import Foundation
import WatchKit

class PostDetailsController: WKInterfaceController {
  @IBOutlet weak var image: WKInterfaceImage!
  @IBOutlet weak var categoryLabel: WKInterfaceLabel!
  @IBOutlet weak var titleLabel: WKInterfaceLabel!
  @IBOutlet weak var dateLabel: WKInterfaceLabel!
  @IBOutlet weak var urlLabel: WKInterfaceLabel!

  var post: Post!

  lazy var dateFormatter: NSDateFormatter = {
    let dateFmt = NSDateFormatter()
    dateFmt.dateStyle = .MediumStyle
    dateFmt.timeStyle = .NoStyle
    return dateFmt
    }()

  override func awakeWithContext(context: AnyObject!) {
    super.awakeWithContext(context)

    if let post = context as? Post {
      self.post = post

      if post.category == "Podcast Episodes" {
        addMenuItemWithItemIcon(.Accept, title: "Mark as Played", action: "markAsRead")
        addMenuItemWithItemIcon(.Play, title: "Play", action: "play")
      } else {
        addMenuItemWithItemIcon(.Accept, title: "Mark as Read", action: Selector("markAsRead"))
      }
    }
  }

  func markAsRead() {
    popController()
  }

  func play() {
    NSLog("I wish we could play audio! :(")
  }

  override func willActivate() {
    super.willActivate()

    if post == nil {
      return
    }

    if post.category == "Announcements" {
      image.setImageNamed("announcement")
    } else if post.category == "Podcast Episodes" {
      image.setImageNamed("podcast")
    } else if post.category == "Video Tutorials" {
      image.setImageNamed("video")
    } else {
      image.setImageNamed("written")
    }

    categoryLabel.setText(post.category)
    titleLabel.setText(post.title)
    dateLabel.setText(dateFormatter.stringFromDate(post.timestamp))
    urlLabel.setText(post.link)
  }
}
